@@ -66,9 +66,9 @@ extern "C"
 {
   // The PQnoticeProcessor that receives an error or warning from libpq and
   // sends it to the appropriate connection for processing.
-  void pqxx_notice_processor(void *conn, char const *msg) noexcept
+  void pqxx_notice_processor(void *cx, char const *msg) noexcept
   {
-    reinterpret_cast<pqxx::connection *>(conn)->process_notice(msg);
+    reinterpret_cast<pqxx::connection *>(cx)->process_notice(msg);
   }
 
 
@@ -114,7 +114,11 @@ pqxx::connection::connection(
   if (m_conn == nullptr)
     throw std::bad_alloc{};
   if (status() == CONNECTION_BAD)
+  {
+    PQfinish(m_conn);
+    m_conn = nullptr;
     throw pqxx::broken_connection{PQerrorMessage(m_conn)};
+  }
 }
 
 
@@ -336,8 +340,7 @@ void pqxx::connection::process_notice_raw(char const msg[]) noexcept
     return;
   auto const rbegin = std::crbegin(m_errorhandlers),
              rend = std::crend(m_errorhandlers);
-  for (auto i{rbegin}; (i != rend) and (**i)(msg); ++i)
-    ;
+  for (auto i{rbegin}; (i != rend) and (**i)(msg); ++i);
 }
 
 
@@ -550,9 +553,9 @@ using notify_ptr = std::unique_ptr<PGnotify, void (*)(void const *)>;
 
 
 /// Get one notification from a connection, or null.
-notify_ptr get_notif(pqxx::internal::pq::PGconn *conn)
+notify_ptr get_notif(pqxx::internal::pq::PGconn *cx)
 {
-  return {PQnotifies(conn), pqxx::internal::pq::pqfreemem};
+  return {PQnotifies(cx), pqxx::internal::pq::pqfreemem};
 }
 } // namespace
 
