@@ -25,6 +25,7 @@
 #include "pqxx/internal/header-pre.hxx"
 
 #include "pqxx/except.hxx"
+#include "pqxx/internal/concat.hxx"
 #include "pqxx/strconv.hxx"
 
 #include "pqxx/internal/header-post.hxx"
@@ -39,8 +40,7 @@ namespace
 /** When building with libcxxrt on clang, you can't create thread_local objects
  * of non-POD types.  Any attempt will result in a link error.
  */
-constexpr bool have_thread_local
-{
+constexpr bool have_thread_local{
 #  if defined(PQXX_HAVE_THREAD_LOCAL)
   true
 #  else
@@ -250,9 +250,17 @@ std::string demangle_type_name(char const raw[])
   return std::string{demangled ? demangled.get() : raw};
 }
 
+
+// TODO: Equivalents for converting a null in the other direction.
 void PQXX_COLD throw_null_conversion(std::string const &type)
 {
-  throw conversion_error{"Attempt to convert null to " + type + "."};
+  throw conversion_error{concat("Attempt to convert SQL null to ", type, ".")};
+}
+
+
+void PQXX_COLD throw_null_conversion(std::string_view type)
+{
+  throw conversion_error{concat("Attempt to convert SQL null to ", type, ".")};
 }
 
 
@@ -261,6 +269,7 @@ std::string PQXX_COLD state_buffer_overrun(int have_bytes, int need_bytes)
   // We convert these in standard library terms, not for the localisation
   // so much as to avoid "error cycles," if these values in turn should fail
   // to get enough buffer space.
+  // C++20: Use formatting library.
   std::stringstream have, need;
   have << have_bytes;
   need << need_bytes;
@@ -421,8 +430,7 @@ template<typename T>
   // work _for composite types._  I see no clean way to support leading
   // whitespace there without putting the code in here.  A shame about the
   // overhead, modest as it is, for the normal case.
-  for (; i < std::size(text) and (data[i] == ' ' or data[i] == '\t'); ++i)
-    ;
+  for (; i < std::size(text) and (data[i] == ' ' or data[i] == '\t'); ++i);
   if (i == std::size(text))
     throw pqxx::conversion_error{
       "Converting string to " + pqxx::type_name<T> +
